@@ -1,5 +1,5 @@
 # coding: utf-8
 
 from __future__ import unicode_literals
-from .flaky_decorator import flaky
 
+from flaky.flaky_decorator import flaky
